darkhistory.physics.beta_ion — DarkHistory documentation

# darkhistory.physics.beta_ion

`darkhistory.physics.` `beta_ion`(T_rad, species)

  Case-B photoionization coefficient.

  Parameters: | T_rad : float The radiation temperature. species : {‘HI’, ‘HeI_21s’, ‘HeI_23s’} The relevant species.
  Returns: | float Case-B photoionization coefficient in s-1.

  Notes

  For HeI, returns beta with respect to the 2s state, in agreement with convention in RECFAST.

#### Previous topic

darkhistory.physics.alpha_recomb

#### Next topic

darkhistory.physics.peebles_C

### This Page

Show Source